@@ -4,7 +4,7 @@ import os
 
 from mopidy import config, ext
 
-__version__ = '0.9.0'
+__version__ = '1.6.6'
 
 
 class Extension(ext.Extension):
@@ -31,6 +31,7 @@ class Extension(ext.Extension):
         path = os.path.join(os.path.dirname(__file__), 'www')
         return [
             (r'/', RedirectHandler, {'url': 'index.html'}),
-            (r'/(index.html)', IndexHandler, {'config': config, 'path': path}),
+            (r'/(.*\.html)', IndexHandler, {'config': config, 'path': path}),
+            (r'/(.*\.json)', IndexHandler, {'config': config, 'path': path}),
             (r'/(.*)', StaticHandler, {'path': path})
         ]
